# phoenix_widgets

Phoenix Widgets is widget collections.

## Getting Started

In the `pubspec.yaml` of your flutter project, add the following dependency:

```yaml
dependencies:
  ...
  phoenix_widgets: "^latestVersion"
```

Import it:

```dart
import 'package:phoenix_widgets/phoenix_widgets.dart';
```

---
## PhoenixCard
PhoenixCard is widget to create card

![PhoenixCard](screenshots/phoenix_card.png)


### Usage Examples

```dart
 PhoenixCard(
    title: Text(
      "Title with Image",
      style: Theme.of(context).textTheme.headline6,
    ),
    description: Text(
      "Description",
      style: Theme.of(context).textTheme.bodyText2,
    ),
    footer: Row(
      mainAxisAlignment: MainAxisAlignment.start,
      children: [
        const CircleAvatar(backgroundColor: Colors.red),
        const SizedBox(width: 8),
        Text(
        "Footer",
        style: Theme.of(context).textTheme.headline6,
        )
      ],
    ),
    image: Image.network(
      "https://images.contentstack.io/v3/assets/blt2a130c768c36b9df/blt5f384c7eb51e7cff/5f7d972ddf178b0ea98488e1/banner_sadaqah.jpg?auto=webp",
      fit: BoxFit.cover,
    ),
    onTap: () {},
  ),

```
## Available Parameters 
| Param                       | Type         | isRequired |  Default          |
|-----------------------------|--------------|------------|------------       |
| image                       | Widget       | No         |                   |
| title                       | Widget       | Yes        |                   |
| description                 | Widget       | Yes        |                   |
| footer                      | Widget       | No         |                   |
| width                       | double       | No         | double.maxFinite  |
| padding                     | EdgeInsets   | No         |                   |
| margin                      | EdgeInsets   | No         | const EdgeInsets.symmetric(horizontal: 16,vertical: 8)|
| onTap                       | VoidCallback | No         |                   |
| backgroundColor             | Color        | No         | Colors.white      |
| borderRadius                | double       | No         | 4                 |
-------------------------------------------------------------------------------

---
## PhoenixBottomMenu
PhoenixBottomMenu is widget to create navigation bar 

![PhoenixCard](screenshots/phoenix_bottommenu.png)


### Usage Examples

```dart
PhoenixBottomMenuUHF(
    navBarItems: [
      NavBarItem("Home", 'assets/tab_home.png'),
      NavBarItem("Profile", 'assets/tab_profile.png'),
      NavBarItem("Setting", 'assets/tab_setting.png'),
    ],
    selectedTabColor: Colors.red, ///optional
    unselectedTabColor: Colors.black54, ///optional
    onTabChange: (index) {
    setState(() {});
    _tabController!.jumpToPage(index);
    },
)

```
## Available Parameters
| Param                       | Type            | isRequired |  Default          |
|-----------------------------|-----------------|------------|------------       |
| navBarItems                 | List<NavBarItem>| Yes        |                   |
| selectedTabColor            | Color           | No         | Colors.red        |
| unselectedTabColor          | Color           | No         | Colors.black54    |
| onTabChange                 | Function        | Yes        |                   |
----------------------------------------------------------------------------------

---
## PhoenixButton
PhoenixButton is widget to create button

![PhoenixCard](screenshots/phoenix_button.png)


### Usage Examples

```dart
PhoenixButton(
    ///required
    text: "Click Me !!",
    
    ///optional
    buttonColour: Colors.red,
    buttonElevation: 0.5,
    textColour: Colors.white,
    textScaleFactor: 1.0,
    textAlign: TextAlign.center,
    fontSize: 16.0,
    fontWeight: FontWeight.bold,
    radius: 10.0,
    disableButtonColour: Colors.blue,
    marginLeft: 10.0,
    marginRight: 10.0,
    marginTop: 10.0,
    marginBottom: 10.0,
    paddingTop: 10.0,
    paddingBottom: 100.0,
    paddingLeft: 10.0,
    paddingRight: 10.0,
    height: 100,
    width: double.infinity,
    onPressed: () {
        ScaffoldMessenger.of(context).showSnackBar(const SnackBar(
        content: Text("Button Clicked"),
    ));
    },
),

```
## Available Parameters
| Param                       | Type            | isRequired |  Default          |
|-----------------------------|-----------------|------------|------------       |
| text                        | String          | Yes        |                   |
| buttonColour                | Color           | No         | Colors.red        |
| buttonElevation             | Double          | No         | 0.0               |
| textColour                  | Color           | No         | Colors.white      |
| textScaleFactor             | Double          | No         | 1.0               |
| textAlign                   | TextAlign       | No         | TextAlign.center  |
| fontSize                    | Double          | No         | 16.0              |
| fontWeight                  | FontWeight      | No         | FontWeight.normal |
| radius                      | Double          | No         | 0.0               |
| disableButtonColour         | Color           | No         | #67C1BF           |
| marginLeft                  | Double          | No         |                   |
| marginRight                 | Double          | No         |                   |
| marginTop                   | Double          | No         |                   |
| marginBottom                | Double          | No         |                   |
| paddingTop                  | Double          | No         |                   |
| paddingBottom               | Double          | No         |                   |
| paddingLeft                 | Double          | No         |                   |
| paddingRight                | Double          | No         |                   |
| height                      | Double          | No         |                   |
| width                       | Double          | No         | double.infinity   |
| onPressed                   | VoidCallback    | No         |                   |
----------------------------------------------------------------------------------

---
